==> v-sim_3.5.1.orig.tar.gz: v_sim-3.5.1/src/renderingBackend/visu_actionInterface.h <==
/*   EXTRAITS DE LA LICENCE
	Copyright CEA, contributeurs : Luc BILLARD et Damien
	CALISTE, laboratoire L_Sim, (2001-2005)
  
	Adresse ml :
	BILLARD, non joignable par ml ;
	CALISTE, damien P caliste AT cea P fr.

	Ce logiciel est un programme informatique servant  visualiser des
	structures atomiques dans un rendu pseudo-3D. 

	Ce logiciel est rgi par la licence CeCILL soumise au droit franais et
	respectant les principes de diffusion des logiciels libres. Vous pouvez
	utiliser, modifier et/ou redistribuer ce programme sous les conditions
	de la licence CeCILL telle que diffuse par le CEA, le CNRS et l'INRIA 
	sur le site "http://www.cecill.info".

	Le fait que vous puissiez accder  cet en-tte signifie que vous avez 
	pris connaissance de la licence CeCILL, et que vous en avez accept les
	termes (cf. le fichier Documentation/licence.fr.txt fourni avec ce logiciel).
*/

/*   LICENCE SUM UP
	Copyright CEA, contributors : Luc BILLARD et Damien
	CALISTE, laboratoire L_Sim, (2001-2005)

	E-mail address:
	BILLARD, not reachable any more ;
	CALISTE, damien P caliste AT cea P fr.

	This software is a computer program whose purpose is to visualize atomic
	configurations in 3D.

	This software is governed by the CeCILL  license under French law and
	abiding by the rules of distribution of free software.  You can  use, 
	modify and/ or redistribute the software under the terms of the CeCILL
	license as circulated by CEA, CNRS and INRIA at the following URL
	"http://www.cecill.info". 

	The fact that you are presently reading this means that you have had
	knowledge of the CeCILL license and that you accept its terms. You can
	find a copy of this licence shipped with this software at Documentation/licence.en.txt.
*/
#ifndef VISU_ACTIONINTERFACE_H
#define VISU_ACTIONINTERFACE_H

/**
 * SECTION:visu_actionInterface
 * @short_description: Interface for defining actions and events.
 *
 * <para>These definitions are used to give a library and plateform
 * independent simplified event handlers.</para>
 */

/**
 * BUTTON_TYPE_PRESS:
 *
 * Value that can be put into field buttonType of structure #SimplifiedEvents_struct.
 */
#define BUTTON_TYPE_PRESS   1
/**
 * BUTTON_TYPE_RELEASE:
 *
 * Value that can be put into field buttonType of structure #SimplifiedEvents_struct.
 */
#define BUTTON_TYPE_RELEASE 2

/**
 * SpecialKeyStroke:
 * @Key_None: no key pressed ;
 * @Key_Page_Up: key up ;
 * @Key_Page_Down: key down ;
 * @Key_Arrow_Left: key left ;
 * @Key_Arrow_Right: key right ;
 * @Key_Arrow_Up: key up ;
 * @Key_Arrow_Down: key down.
 *
 * Possible non ascii keys used in #SimplifiedEvents.
 */
typedef enum
  {
    Key_None,
    Key_Page_Up,
    Key_Page_Down,
    Key_Arrow_Left,
    Key_Arrow_Right,
    Key_Arrow_Up,
    Key_Arrow_Down
  } SpecialKeyStroke;
/**
 * SimplifiedEvents_struct:
 * @x: the position x (on parent) for the event ;
 * @y: the position y (on parent) for the event ;
 * @button: the number of the button, 0 if not a button event ;
 * @buttonType: #BUTTON_TYPE_PRESS or #BUTTON_TYPE_RELEASE ;
 * @shiftMod: TRUE if Shift key is pressed during the event ;
 * @controlMod: TRUE if Control key is pressed during the event ;
 * @motion: TRUE if the event is a motion ;
 * @letter: The value of the letter if the event is a key stroke '\0' if not ;
 * @specialKey: the value of a special key if the event is a key stroke
 *              but not with an ascii letter.
 *
 * This structure is a common interface for events (inspired from X). We don't
 * use the one introduced by GDK because we don't want this dependency be a
 * limitation.
 */
struct SimplifiedEvents_struct
{
  int x, y;
  unsigned int button;
  int buttonType;
  int shiftMod, controlMod;
  int motion;
  char letter;
  SpecialKeyStroke specialKey;
};
/**
 * SimplifiedEvents:
 *
 * A short way to address SimplifiedEvents_struct objects.
 */
typedef struct SimplifiedEvents_struct SimplifiedEvents;


#endif

==> v-sim_3.7.0.orig.tar.gz: v_sim-3.7.0/src/renderingBackend/visu_actionInterface.h <==
/*   EXTRAITS DE LA LICENCE
	Copyright CEA, contributeurs : Luc BILLARD et Damien
	CALISTE, laboratoire L_Sim, (2001-2005)
  
	Adresse ml :
	BILLARD, non joignable par ml ;
	CALISTE, damien P caliste AT cea P fr.

	Ce logiciel est un programme informatique servant  visualiser des
	structures atomiques dans un rendu pseudo-3D. 

	Ce logiciel est rgi par la licence CeCILL soumise au droit franais et
	respectant les principes de diffusion des logiciels libres. Vous pouvez
	utiliser, modifier et/ou redistribuer ce programme sous les conditions
	de la licence CeCILL telle que diffuse par le CEA, le CNRS et l'INRIA 
	sur le site "http://www.cecill.info".

	Le fait que vous puissiez accder  cet en-tte signifie que vous avez 
	pris connaissance de la licence CeCILL, et que vous en avez accept les
	termes (cf. le fichier Documentation/licence.fr.txt fourni avec ce logiciel).
*/

/*   LICENCE SUM UP
	Copyright CEA, contributors : Luc BILLARD et Damien
	CALISTE, laboratoire L_Sim, (2001-2005)

	E-mail address:
	BILLARD, not reachable any more ;
	CALISTE, damien P caliste AT cea P fr.

	This software is a computer program whose purpose is to visualize atomic
	configurations in 3D.

	This software is governed by the CeCILL  license under French law and
	abiding by the rules of distribution of free software.  You can  use, 
	modify and/ or redistribute the software under the terms of the CeCILL
	license as circulated by CEA, CNRS and INRIA at the following URL
	"http://www.cecill.info". 

	The fact that you are presently reading this means that you have had
	knowledge of the CeCILL license and that you accept its terms. You can
	find a copy of this licence shipped with this software at Documentation/licence.en.txt.
*/
#ifndef VISU_ACTIONINTERFACE_H
#define VISU_ACTIONINTERFACE_H

/**
 * SECTION:visu_actionInterface
 * @short_description: Interface for defining actions and events.
 *
 * <para>These definitions are used to give a library and plateform
 * independent simplified event handlers.</para>
 */

/**
 * TOOL_BUTTON_TYPE_PRESS:
 *
 * Value that can be put into field buttonType of structure #_ToolSimplifiedEvents.
 */
#define TOOL_BUTTON_TYPE_PRESS   1
/**
 * TOOL_BUTTON_TYPE_RELEASE:
 *
 * Value that can be put into field buttonType of structure #_ToolSimplifiedEvents.
 */
#define TOOL_BUTTON_TYPE_RELEASE 2

/**
 * ToolSpecialKeyStroke:
 * @Key_None: no key pressed ;
 * @Key_Page_Up: key up ;
 * @Key_Page_Down: key down ;
 * @Key_Arrow_Left: key left ;
 * @Key_Arrow_Right: key right ;
 * @Key_Arrow_Up: key up ;
 * @Key_Arrow_Down: key down ;
 * @Key_Menu: key menu.
 *
 * Possible non ascii keys used in #ToolSimplifiedEvents.
 */
typedef enum
  {
    Key_None,
    Key_Page_Up,
    Key_Page_Down,
    Key_Arrow_Left,
    Key_Arrow_Right,
    Key_Arrow_Up,
    Key_Arrow_Down,
    Key_Menu
  } ToolSpecialKeyStroke;

/**
 * ToolSimplifiedEvents:
 * @x: the position x (on parent) for the event ;
 * @y: the position y (on parent) for the event ;
 * @root_x: the position x (in root window) for the event ;
 * @root_y: the position y (in root window) for the event ;
 * @button: the number of the button, 0 if not a button event ;
 * @buttonType: #TOOL_BUTTON_TYPE_PRESS or #TOOL_BUTTON_TYPE_RELEASE ;
 * @shiftMod: TRUE if Shift key is pressed during the event ;
 * @controlMod: TRUE if Control key is pressed during the event ;
 * @motion: TRUE if the event is a motion ;
 * @letter: The value of the letter if the event is a key stroke '\0' if not ;
 * @specialKey: the value of a special key if the event is a key stroke
 *              but not with an ascii letter.
 *
 * This structure is a common interface for events (inspired from X). We don't
 * use the one introduced by GDK because we don't want this dependency be a
 * limitation.
 */
typedef struct _ToolSimplifiedEvents ToolSimplifiedEvents;
struct _ToolSimplifiedEvents
{
  int x, y;
  int root_x, root_y;
  guint button;
  int buttonType;
  int shiftMod, controlMod;
  int motion;
  char letter;
  ToolSpecialKeyStroke specialKey;
};


#endif
